==> cxf-testutils-3.3.5-sources.jar: org/apache/handlers/types/ObjectFactory.java <==

package org.apache.handlers.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.handlers.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AddNumbersResponse_QNAME = new QName("http://apache.org/handlers/types", "addNumbersResponse");
    private final static QName _AddNumbers_QNAME = new QName("http://apache.org/handlers/types", "addNumbers");
    private final static QName _FaultDetail_QNAME = new QName("http://apache.org/handlers/types", "FaultDetail");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.handlers.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AddNumbersResponse }
     * 
     */
    public AddNumbersResponse createAddNumbersResponse() {
        return new AddNumbersResponse();
    }

    /**
     * Create an instance of {@link AddNumbers }
     * 
     */
    public AddNumbers createAddNumbers() {
        return new AddNumbers();
    }

    /**
     * Create an instance of {@link FaultDetail }
     * 
     */
    public FaultDetail createFaultDetail() {
        return new FaultDetail();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddNumbersResponse }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AddNumbersResponse }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/handlers/types", name = "addNumbersResponse")
    public JAXBElement<AddNumbersResponse> createAddNumbersResponse(AddNumbersResponse value) {
        return new JAXBElement<AddNumbersResponse>(_AddNumbersResponse_QNAME, AddNumbersResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddNumbers }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AddNumbers }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/handlers/types", name = "addNumbers")
    public JAXBElement<AddNumbers> createAddNumbers(AddNumbers value) {
        return new JAXBElement<AddNumbers>(_AddNumbers_QNAME, AddNumbers.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FaultDetail }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link FaultDetail }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/handlers/types", name = "FaultDetail")
    public JAXBElement<FaultDetail> createFaultDetail(FaultDetail value) {
        return new JAXBElement<FaultDetail>(_FaultDetail_QNAME, FaultDetail.class, null, value);
    }

}

==> cxf-testutils-3.3.12-sources.jar: org/apache/handlers/types/ObjectFactory.java <==

package org.apache.handlers.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.handlers.types package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AddNumbersResponse_QNAME = new QName("http://apache.org/handlers/types", "addNumbersResponse");
    private final static QName _AddNumbers_QNAME = new QName("http://apache.org/handlers/types", "addNumbers");
    private final static QName _FaultDetail_QNAME = new QName("http://apache.org/handlers/types", "FaultDetail");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.handlers.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AddNumbersResponse }
     * 
     */
    public AddNumbersResponse createAddNumbersResponse() {
        return new AddNumbersResponse();
    }

    /**
     * Create an instance of {@link AddNumbers }
     * 
     */
    public AddNumbers createAddNumbers() {
        return new AddNumbers();
    }

    /**
     * Create an instance of {@link FaultDetail }
     * 
     */
    public FaultDetail createFaultDetail() {
        return new FaultDetail();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddNumbersResponse }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AddNumbersResponse }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/handlers/types", name = "addNumbersResponse")
    public JAXBElement<AddNumbersResponse> createAddNumbersResponse(AddNumbersResponse value) {
        return new JAXBElement<AddNumbersResponse>(_AddNumbersResponse_QNAME, AddNumbersResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddNumbers }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AddNumbers }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/handlers/types", name = "addNumbers")
    public JAXBElement<AddNumbers> createAddNumbers(AddNumbers value) {
        return new JAXBElement<AddNumbers>(_AddNumbers_QNAME, AddNumbers.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FaultDetail }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link FaultDetail }{@code >}
     */
    @XmlElementDecl(namespace = "http://apache.org/handlers/types", name = "FaultDetail")
    public JAXBElement<FaultDetail> createFaultDetail(FaultDetail value) {
        return new JAXBElement<FaultDetail>(_FaultDetail_QNAME, FaultDetail.class, null, value);
    }

}
